pub async fn exec_ex(
config: Config,
args: &ArgMatches,
extract_descriptions: ExtractDescriptions,
) -> Result<()>Expand description
Like exec, but lets you specify a custom a function to extract a schema from a file.
pub async fn exec_ex(
config: Config,
args: &ArgMatches,
extract_descriptions: ExtractDescriptions,
) -> Result<()>Like exec, but lets you specify a custom a function to extract a schema from a file.