pub fn define_enum_for_sum(
module: &ModuleDef,
out: &mut CodeIndenter<String>,
name: &str,
variants: &[(Identifier, AlgebraicTypeUse)],
)Expand description
Generate a file which defines an enum corresponding to the sum_type.
pub fn define_enum_for_sum(
module: &ModuleDef,
out: &mut CodeIndenter<String>,
name: &str,
variants: &[(Identifier, AlgebraicTypeUse)],
)Generate a file which defines an enum corresponding to the sum_type.