Module util

Module util 

Structs

AuthHeader

Enums

ModuleLanguage

Constants

UNSTABLE_WARNING
VALID_PROTOCOLS

Functions

add_auth_header_opt
Add an authorization header, if provided, to the request builder.
contains_protocol
database_identity
Determine the identity of the database.
decode_identity
detect_module_language
get_auth_header
Gets the auth_header for a request to the server depending on how you want to identify yourself. If you specify anon_identity = true then no auth_header is returned. If you specify an identity this function will try to find the identity in the config file. If no identity can be found, the program will exit(1). If you do not specify an identity this function will either get the default identity if one exists or create and save a new default identity returning the one that was just created.
get_login_token_or_log_in
host_or_url_to_host_and_protocol
resolve_sibling_binary
spacetime_dns
Converts a name to a database identity.
spacetime_reverse_dns
Returns all known names for the given identity.
spacetime_server_fingerprint
unauth_error_context
url_to_host_and_protocol
y_or_n
Prompt the user for y or n from stdin.