Generate a mod.rs as the entry point into the autogenerated code.
Generate a file which defines a struct corresponding to the reducer’s arguments,
implements spacetimedb_client_sdk::table::Reducer for it, and defines a helper
function which invokes the reducer.
Generate a file which defines an enum corresponding to the sum_type.
Generate a file which defines a struct corresponding to the table’s ProductType,
and implements spacetimedb_client_sdk::table::TableType for it.
Generate a file which defines a struct corresponding to the product type.