Structs
Enums
Constants
Functions
- add_
auth_ header_ opt - Add an authorization header, if provided, to the request
builder. - contains_
protocol - database_
identity - Determine the identity of the
database. - decode_
identity - detect_
module_ language - get_
auth_ header - Gets the
auth_headerfor a request to the server depending on how you want to identify yourself. If you specifyanon_identity = truethen noauth_headeris returned. If you specify an identity this function will try to find the identity in the config file. If no identity can be found, the program willexit(1). If you do not specify an identity this function will either get the default identity if one exists or create and save a new default identity returning the one that was just created. - get_
login_ token_ or_ log_ in - host_
or_ url_ to_ host_ and_ protocol - resolve_
sibling_ binary - spacetime_
dns - Converts a name to a database identity.
- spacetime_
reverse_ dns - Returns all known names for the given identity.
- spacetime_
server_ fingerprint - unauth_
error_ context - url_
to_ host_ and_ protocol - y_or_n
- Prompt the user for
yornfrom stdin.