Structs
Enums
Constants
Functions
- add_
auth_ header_ opt - Add an authorization header, if provided, to the request
builder. - contains_
protocol - database_
address - Determine the address of the
database. - describe_
reducer - detect_
module_ language - get_
auth_ header - Gets the
auth_headerfor a request to the server depending on how you want to identify yourself. If you specifyanon_identity = truethen noauth_headeris returned. If you specify an identity this function will try to find the identity in the config file. If no identity can be found, the program willexit(1). If you do not specify an identity this function will either get the default identity if one exists or create and save a new default identity returning the one that was just created. - get_
auth_ header_ only - See
get_auth_header. - host_
or_ url_ to_ host_ and_ protocol - init_
default - is_
hex_ identity - print_
identity_ config - select_
identity_ config - Selects an
identity_configfrom the config file. If you specify the identity it will either return theidentity_configfor the specified identity, or return an error if it cannot be found. If you do not specify an identity this function will either get the default identity if one exists or create and save a new default identity. - spacetime_
dns - Converts a name to a database address.
- spacetime_
register_ tld - Registers the given top level domain to the given identity. If None is passed in as identity, the default identity will be looked up in the config and it will be used instead. Returns Ok() if the domain is successfully registered, returns Err otherwise.
- spacetime_
reverse_ dns - Returns all known names for the given address.
- spacetime_
server_ fingerprint - unauth_
error_ context - url_
to_ host_ and_ protocol - y_or_n
- Prompt the user for
yornfrom stdin.