Module spacetimedb_cli::util

source ·

Structs

Enums

Constants

Functions

  • Gets the auth_header for a request to the server depending on how you want to identify yourself. If you specify anon_identity = true then no auth_header is returned. If you specify an identity this function will try to find the identity in the config file. If no identity can be found, the program will exit(1). If you do not specify an identity this function will either get the default identity if one exists or create and save a new default identity returning the one that was just created.
  • Selects an identity_config from the config file. If you specify the identity it will either return the identity_config for the specified identity, or return an error if it cannot be found. If you do not specify an identity this function will either get the default identity if one exists or create and save a new default identity.
  • Converts a name to a database address.
  • Registers the given top level domain to the given identity. If None is passed in as identity, the default identity will be looked up in the config and it will be used instead. Returns Ok() if the domain is successfully registered, returns Err otherwise.
  • Returns all known names for the given address.